@@ -27,9 +27,9 @@
 #include "msdos.h"
 #include "stream.h"
 
-static ssize_t force_io(Stream_t *Stream,
-			char *buf, mt_off_t start, size_t len,
-			ssize_t (*io)(Stream_t *, char *, mt_off_t, size_t))
+static ssize_t force_pio(Stream_t *Stream,
+			 char *buf, mt_off_t start, size_t len,
+			 ssize_t (*io)(Stream_t *, char *, mt_off_t, size_t))
 {
 	ssize_t ret;
 	int done=0;
@@ -51,14 +51,25 @@ static ssize_t force_io(Stream_t *Stream,
 	return done;
 }
 
-ssize_t force_write(Stream_t *Stream, char *buf, mt_off_t start, size_t len)
+static ssize_t write_wrapper(Stream_t *Stream,  char *buf,
+			     mt_off_t start UNUSEDP, size_t len)
 {
-	return force_io(Stream, buf, start, len,
-			Stream->Class->write);
+	return Stream->Class->write(Stream, buf, len);
 }
 
-ssize_t force_read(Stream_t *Stream, char *buf, mt_off_t start, size_t len)
+ssize_t force_write(Stream_t *Stream, char *buf, size_t len)
 {
-	return force_io(Stream, buf, start, len,
-					Stream->Class->read);
+	return force_pio(Stream, buf, 0, len, write_wrapper);
+}
+
+ssize_t force_pwrite(Stream_t *Stream, char *buf, mt_off_t start, size_t len)
+{
+	return force_pio(Stream, buf, start, len,
+			 Stream->Class->pwrite);
+}
+
+ssize_t force_pread(Stream_t *Stream, char *buf, mt_off_t start, size_t len)
+{
+	return force_pio(Stream, buf, start, len,
+			 Stream->Class->pread);
 }
